==> kdevplatform-4.90.91.tar.xz: kdevplatform-4.90.91/shell/settings/environmentgroupmodel.h <==
/* This file is part of KDevelop
Copyright 2007 Andreas Pakulat <apaku@gmx.de>

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public License
along with this library; see the file COPYING.LIB.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/

#ifndef KDEVPLATFORM_ENVIRONMENTGROUPMODEL_H
#define KDEVPLATFORM_ENVIRONMENTGROUPMODEL_H

#include <QtCore/QAbstractTableModel>
#include <QtCore/QStringList>
#include "util/environmentgrouplist.h"

class QVariant;
class QModelIndex;

namespace KDevelop
{


class EnvironmentGroupModel : public QAbstractTableModel, public EnvironmentGroupList
{
    Q_OBJECT
public:
    enum Role {
        VariableRole = Qt::UserRole + 1,
        ValueRole
    };

    enum Column {
        VariableColumn,
        ValueColumn
    };

    EnvironmentGroupModel();
    int rowCount( const QModelIndex &parent = QModelIndex() ) const override;
    int columnCount( const QModelIndex &parent = QModelIndex()  ) const override;
    Qt::ItemFlags flags( const QModelIndex& idx ) const override;
    QVariant data( const QModelIndex& idx, int role = Qt::DisplayRole) const override;
    QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
    bool setData( const QModelIndex& idx, const QVariant&, int role = Qt::EditRole) override;
    void setCurrentGroup( const QString& group );
    bool cloneCurrentGroup( const QString& newGroup );
    void loadFromConfig( KConfig* );
    void saveToConfig( KConfig* );
    QModelIndex addVariable( const QString& var, const QString& value );
    void removeVariable(const QString& variable);
    void removeVariables(const QStringList& variables);
    void removeGroup( const QString& grp );
    void changeDefaultGroup( const QString& grp );

private:
    QStringList m_varsByIndex;
    QString m_currentGroup;
};

}

#endif

==> kdevplatform_5.0.3.orig.tar.xz: kdevplatform-5.0.3/shell/settings/environmentgroupmodel.h <==
/* This file is part of KDevelop
Copyright 2007 Andreas Pakulat <apaku@gmx.de>

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public License
along with this library; see the file COPYING.LIB.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/

#ifndef KDEVPLATFORM_ENVIRONMENTGROUPMODEL_H
#define KDEVPLATFORM_ENVIRONMENTGROUPMODEL_H

#include <QtCore/QAbstractTableModel>
#include <QtCore/QStringList>
#include "util/environmentgrouplist.h"

class QVariant;
class QModelIndex;

namespace KDevelop
{


class EnvironmentGroupModel : public QAbstractTableModel, public EnvironmentGroupList
{
    Q_OBJECT
public:
    enum Role {
        VariableRole = Qt::UserRole + 1,
        ValueRole
    };

    enum Column {
        VariableColumn,
        ValueColumn
    };

    EnvironmentGroupModel();
    int rowCount( const QModelIndex &parent = QModelIndex() ) const override;
    int columnCount( const QModelIndex &parent = QModelIndex()  ) const override;
    Qt::ItemFlags flags( const QModelIndex& idx ) const override;
    QVariant data( const QModelIndex& idx, int role = Qt::DisplayRole) const override;
    QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
    bool setData( const QModelIndex& idx, const QVariant&, int role = Qt::EditRole) override;
    void setCurrentGroup( const QString& group );
    bool cloneCurrentGroup( const QString& newGroup );

    /**
     * Load a set of environment variables from a string.
     *
     * @p plainText In the form "FOO=1\nBAR=2"
     */
    void loadEnvironmentFromString(const QString& plainText);

    void loadFromConfig( KConfig* );
    void saveToConfig( KConfig* );
    QModelIndex addVariable( const QString& var, const QString& value );
    void removeVariable(const QString& variable);
    void removeVariables(const QStringList& variables);
    void removeGroup( const QString& grp );
    void changeDefaultGroup( const QString& grp );

private:
    QStringList m_varsByIndex;
    QString m_currentGroup;
};

}

#endif
